@@ -50,7 +50,7 @@ _test_mode = False
 
 # The name of the folder containing the standard learning trees.
 # Relative to the installation dir.
-exercises_dir = u"exercises/standard"
+exercises_dir = os.path.join(u"exercises", u"standard")
 _abs_exercises_dir = os.path.join(os.getcwdu(), exercises_dir) + os.sep
 
 solfege_uri = u"solfege:"
@@ -1764,6 +1764,12 @@ class ElembuilderLessonfile(QuestionsLessonfile):
         super(ElembuilderLessonfile, self).parse_string(s, really_filename)
         # We need the name variable for statistics
         self.discard_questions_without_name()
+        # question['elements'] should always be a list. If a question allows
+        # a single element as answer one gets a dict from parse_string and not
+        # a list. Thus we pack the dict in a list and are happy.
+        for question in self.m_questions:
+            if type(question['elements']) <> (type([])):
+                question['elements'] = [question['elements']]
         # This loop let us use normal strings and lesson file functions
         # like pangomarkup as element labels.
         for question in self.m_questions:
